@@ -2,6 +2,7 @@
 import copy
 import logging
 import os
+import pathlib
 import subprocess
 import sys
 from argparse import Namespace
@@ -206,14 +207,31 @@ class Lintable:
 def discover_lintables(options: Namespace) -> Dict[str, Any]:
     """Find all files that we know how to lint."""
     # git is preferred as it also considers .gitignore
-    git_command = ['git', 'ls-files', '-z']
+    git_command_present = [
+        'git',
+        'ls-files',
+        '--cached',
+        '--others',
+        '--exclude-standard',
+        '-z',
+    ]
+    git_command_absent = ['git', 'ls-files', '--deleted', '-z']
     out = None
 
     try:
-        out = subprocess.check_output(
-            git_command, stderr=subprocess.STDOUT, universal_newlines=True
+        out_present = subprocess.check_output(
+            git_command_present, stderr=subprocess.STDOUT, universal_newlines=True
         ).split("\x00")[:-1]
-        _logger.info("Discovered files to lint using: %s", ' '.join(git_command))
+        _logger.info(
+            "Discovered files to lint using: %s", ' '.join(git_command_present)
+        )
+
+        out_absent = subprocess.check_output(
+            git_command_absent, stderr=subprocess.STDOUT, universal_newlines=True
+        ).split("\x00")[:-1]
+        _logger.info("Excluded removed files using: %s", ' '.join(git_command_absent))
+
+        out = set(out_present) - set(out_absent)
     except subprocess.CalledProcessError as exc:
         if not (exc.returncode == 128 and 'fatal: not a git repository' in exc.output):
             _logger.warning(
@@ -227,29 +245,52 @@ def discover_lintables(options: Namespace) -> Dict[str, Any]:
     if out is None:
         exclude_pattern = "|".join(str(x) for x in options.exclude_paths)
         _logger.info("Looking up for files, excluding %s ...", exclude_pattern)
-        out = WcMatch('.', exclude_pattern=exclude_pattern, flags=RECURSIVE).match()
+        out = WcMatch(
+            '.', exclude_pattern=exclude_pattern, flags=RECURSIVE, limit=256
+        ).match()
 
     return OrderedDict.fromkeys(sorted(out))
 
 
-def guess_project_dir() -> str:
-    """Return detected project dir or user home directory."""
-    try:
-        result = subprocess.run(
-            ["git", "rev-parse", "--show-toplevel"],
-            stderr=subprocess.PIPE,
-            stdout=subprocess.PIPE,
-            universal_newlines=True,
-            check=False,
-        )
-    except FileNotFoundError:
-        # if git is absent we use home directory
-        return str(Path.home())
+def guess_project_dir(config_file: str) -> str:
+    """Return detected project dir or current working directory."""
+    path = None
+    if config_file is not None:
+        target = pathlib.Path(config_file)
+        if target.exists():
+            path = str(target.parent.absolute())
 
-    if result.returncode != 0:
-        return str(Path.home())
+    if path is None:
+        try:
+            result = subprocess.run(
+                ["git", "rev-parse", "--show-toplevel"],
+                stderr=subprocess.PIPE,
+                stdout=subprocess.PIPE,
+                universal_newlines=True,
+                check=False,
+            )
 
-    return result.stdout.splitlines()[0]
+            path = result.stdout.splitlines()[0]
+        except subprocess.CalledProcessError as exc:
+            if not (
+                exc.returncode == 128 and 'fatal: not a git repository' in exc.output
+            ):
+                _logger.warning(
+                    "Failed to guess project directory using git: %s",
+                    exc.output.rstrip('\n'),
+                )
+        except FileNotFoundError as exc:
+            _logger.warning("Failed to locate command: %s", exc)
+
+    if path is None:
+        path = os.getcwd()
+
+    _logger.info(
+        "Guessed %s as project root directory",
+        path,
+    )
+
+    return path
 
 
 def expand_dirs_in_lintables(lintables: Set[Lintable]) -> None:
