@@ -1,6 +1,7 @@
 import pytest
 
 from ansiblelint.file_utils import Lintable
+from ansiblelint.runner import Runner
 
 IMPORT_TASKS_MAIN = Lintable(
     'import-tasks-main.yml',
@@ -39,7 +40,7 @@ PLAY_IMPORT_TASKS = Lintable(
     indirect=['_play_files'],
 )
 @pytest.mark.usefixtures('_play_files')
-def test_import_tasks_with_malformed_import(runner):
+def test_import_tasks_with_malformed_import(runner: Runner) -> None:
     results = runner.run()
     passed = False
     for result in results:
